# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .branch_protection import *
from .deploy_key import *
from .deploy_key_enable import *
from .deploy_token import *
from .get_group import *
from .get_group_membership import *
from .get_project import *
from .get_projects import *
from .get_user import *
from .get_users import *
from .group import *
from .group_cluster import *
from .group_label import *
from .group_ldap_link import *
from .group_membership import *
from .group_share_group import *
from .group_variable import *
from .instance_cluster import *
from .instance_variable import *
from .label import *
from .pipeline_schedule import *
from .pipeline_schedule_variable import *
from .pipeline_trigger import *
from .project import *
from .project_approval_rule import *
from .project_badge import *
from .project_cluster import *
from .project_freeze_period import *
from .project_hook import *
from .project_level_mr_approvals import *
from .project_membership import *
from .project_mirror import *
from .project_share_group import *
from .project_variable import *
from .provider import *
from .service_github import *
from .service_jira import *
from .service_pipelines_email import *
from .service_slack import *
from .tag_protection import *
from .user import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_gitlab.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_gitlab.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "gitlab",
  "mod": "index/branchProtection",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/branchProtection:BranchProtection": "BranchProtection"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/deployKey",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/deployKey:DeployKey": "DeployKey"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/deployKeyEnable",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/deployKeyEnable:DeployKeyEnable": "DeployKeyEnable"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/deployToken",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/deployToken:DeployToken": "DeployToken"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/group",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/group:Group": "Group"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupCluster",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupCluster:GroupCluster": "GroupCluster"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupLabel",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupLabel:GroupLabel": "GroupLabel"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupLdapLink",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupLdapLink:GroupLdapLink": "GroupLdapLink"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupMembership",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupShareGroup",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupShareGroup:GroupShareGroup": "GroupShareGroup"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/groupVariable",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/groupVariable:GroupVariable": "GroupVariable"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/instanceCluster",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/instanceCluster:InstanceCluster": "InstanceCluster"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/instanceVariable",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/instanceVariable:InstanceVariable": "InstanceVariable"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/label",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/label:Label": "Label"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/pipelineSchedule",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/pipelineSchedule:PipelineSchedule": "PipelineSchedule"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/pipelineScheduleVariable",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/pipelineScheduleVariable:PipelineScheduleVariable": "PipelineScheduleVariable"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/pipelineTrigger",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/pipelineTrigger:PipelineTrigger": "PipelineTrigger"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/project",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/project:Project": "Project"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectApprovalRule",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectApprovalRule:ProjectApprovalRule": "ProjectApprovalRule"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectBadge",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectBadge:ProjectBadge": "ProjectBadge"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectCluster",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectCluster:ProjectCluster": "ProjectCluster"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectFreezePeriod",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectFreezePeriod:ProjectFreezePeriod": "ProjectFreezePeriod"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectHook",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectHook:ProjectHook": "ProjectHook"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectLevelMrApprovals",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectLevelMrApprovals:ProjectLevelMrApprovals": "ProjectLevelMrApprovals"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectMembership",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectMembership:ProjectMembership": "ProjectMembership"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectMirror",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectMirror:ProjectMirror": "ProjectMirror"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectShareGroup",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectShareGroup:ProjectShareGroup": "ProjectShareGroup"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/projectVariable",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/projectVariable:ProjectVariable": "ProjectVariable"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/serviceGithub",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/serviceGithub:ServiceGithub": "ServiceGithub"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/serviceJira",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/serviceJira:ServiceJira": "ServiceJira"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/servicePipelinesEmail",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/servicePipelinesEmail:ServicePipelinesEmail": "ServicePipelinesEmail"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/serviceSlack",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/serviceSlack:ServiceSlack": "ServiceSlack"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/tagProtection",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/tagProtection:TagProtection": "TagProtection"
  }
 },
 {
  "pkg": "gitlab",
  "mod": "index/user",
  "fqn": "pulumi_gitlab",
  "classes": {
   "gitlab:index/user:User": "User"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "gitlab",
  "token": "pulumi:providers:gitlab",
  "fqn": "pulumi_gitlab",
  "class": "Provider"
 }
]
"""
)
